@@ -1,6 +1,6 @@
 #' The \emph{isFitLogit} is a simple check if object inherits either "lrm" 
 #' class or inherits the  "glm" class together with a "logit" link 
-#' funciton indicating that it is a logistic function.
+#' function indicating that it is a logistic function.
 #'
 #' @rdname isFitFn
 #' 
@@ -8,12 +8,14 @@
 #' 
 #' @export
 isFitLogit <- function(fit){
-  if ("lrm" %in% class(fit))
-    return (TRUE)
+  if ("lrm" %in% class(fit)) {
+    return(TRUE)
+  }
   
-  if ("glm" %in% class(fit) &&
-    fit$family$link == "logit")
-    return (TRUE)
+  if (inherits(fit, "glm") &&
+    family(fit)$family == "binomial") {
+    return(TRUE)
+  }
   
-  return (FALSE)  
+  return(FALSE)  
 }
